@@ -10,7 +10,7 @@ minor=strtonum("0x" substr(h, 5, 2))
 patch=strtonum("0x" substr(h, 7, 2)) / 2
 printf "oldVersion=\"%d.%d.%d\"\n", major, minor, patch
 printf "newVersion=\"%d.%d.%d\"\n", major, minor, patch + 1
-}' include/Vc/version.h`
+}' Vc/version.h`
 echo    "current version: $oldVersion"
 echo -n "    new release: "
 read -e -i "$newVersion" newVersion
@@ -26,17 +26,27 @@ sed -i \
 sed -i \
 	-e "s/Vc_VERSION_STRING \".*\"\$/Vc_VERSION_STRING \"$versionString\"/" \
 	-e "s/Vc_VERSION_NUMBER 0x.*\$/Vc_VERSION_NUMBER $versionNumber/" \
-	include/Vc/version.h
-cat include/Vc/version.h
+	Vc/version.h
+cat Vc/version.h
+
+# Modify README.md to link to release docs
+ed README.md <<EOF
+P
+/github.io/a
+* [$versionString release](https://vcdevel.github.io/Vc-$versionString/)
+.
+w
+EOF
 
 # Don't build tests with make all
 sed -i -e 's/#Release# //' CMakeLists.txt
-git commit CMakeLists.txt doc/Doxyfile include/Vc/version.h -s -F- <<EOF
+git commit README.md CMakeLists.txt doc/Doxyfile Vc/version.h -s -F- <<EOF
 release: version $versionString
 
 * change version strings/numbers to $versionString
 * disable HTML_TIMESTAMP for doxygen
 * don't build tests with make all
+* Add documentation link to Vc-$versionString
 EOF
 
 git tag -m "Vc $versionString release" -s "$versionString" || exit
@@ -46,12 +56,25 @@ git archive --format=tar --prefix="Vc-$versionString/" "$versionString" | gzip >
 
 # Create API docs tarball
 ./makeApidox.sh
+
+# Copy API docs to vcdevel.github.io
+git clone --depth 2 git@github.com:VcDevel/vcdevel.github.io && \
+cp -a doc/html vcdevel.github.io/Vc-$versionString && \
+cd vcdevel.github.io && \
+git add Vc-$versionString && \
+git commit -m "Add Vc $versionString release docs" && \
+git push && \
+cd .. && \
+rm -r vcdevel.github.io
+
+# Create API docs tarball
 mv doc/html/*.qch "../Vc-${versionString}.qch"
 mv doc/html "Vc-docs-$versionString" && tar -czf "../Vc-docs-$versionString".tar.gz "Vc-docs-$versionString"
 rm -rf "Vc-docs-$versionString"
 
 # Get back to the state before the tag and fix up the version numbers afterwards
 git revert -n HEAD
+git reset HEAD README.md && git checkout README.md
 
 # Update the version number of the after-release code
 versionString="$versionString-dev"
@@ -64,8 +87,8 @@ sed -i \
 sed -i \
 	-e "s/Vc_VERSION_STRING \".*\"\$/Vc_VERSION_STRING \"$versionString\"/" \
 	-e "s/Vc_VERSION_NUMBER 0x.*\$/Vc_VERSION_NUMBER $versionNumber/" \
-	include/Vc/version.h
-git commit CMakeLists.txt doc/Doxyfile include/Vc/version.h -s -F- <<EOF
+	Vc/version.h
+git commit CMakeLists.txt doc/Doxyfile Vc/version.h -s -F- <<EOF
 after release: version $versionString
 
 * change version strings/numbers to $versionString
